@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,7 +32,7 @@ class ImportCalendarPage : public QWidget
     Q_OBJECT
 
 public:
-    explicit ImportCalendarPage(QWidget *parent = Q_NULLPTR);
+    explicit ImportCalendarPage(QWidget *parent = nullptr);
     ~ImportCalendarPage();
 
     void addImportInfo(const QString &log);
