@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,6 +20,7 @@
 #define IMPORTWIZARD_H
 
 #include "abstractimporter.h"
+#include "libimportwizard_export.h"
 
 #include <KAssistantDialog>
 
@@ -40,7 +41,7 @@ namespace Akonadi
 {
 class Collection;
 }
-class ImportWizard : public KAssistantDialog
+class LIBIMPORTWIZARD_EXPORT ImportWizard : public KAssistantDialog
 {
     Q_OBJECT
 public:
@@ -49,7 +50,7 @@ public:
         Manual = 1
     };
 
-    explicit ImportWizard(WizardMode mode, QWidget *parent = Q_NULLPTR);
+    explicit ImportWizard(WizardMode mode, QWidget *parent = nullptr);
     ~ImportWizard();
 
     void next() Q_DECL_OVERRIDE;
